
# Guidelines for microscope usage and booking rules at the SciLifeLab Cryo-EM Facility 
(also available at <https://cryoem.scilifelab.se/> ):

---
 
1. Every user **MUST** register in the SciLifeLab Cryo-EM portal <https://cryoem.scilifelab.se/> 
 
2. Every user **MUST** indicate the name of their PI upon registering
 
3. Every PI **MUST** register and provide a valid **INVOICE REFERENCE** (every PI will be invoiced individually)
 
4. Microscope sessions can be booked at any of the four microscopes REGARDLESS of whether you want to perform SCREENING or DATA COLLECTION.
 
5. Krios-𝛃 will become available for booking from mid November.
 
7. You will be able to book time per quarter, so you will now be able to book for Oct-Dec. Booking slots for the next quarter will be made available at the end of November.
 
8. During the booking you **MUST** provide information about what TYPE OF EXPERIMENT you want to perform using the dedicated form attached to the booking.
 
9. We suggest you book sessions of 48 hours or more for data collection. 
 
10. Cancellation of a booking is possible up to 48 hours from the start of the session. 
 
11. We suggest you book sessions for data collection starting on Mondays.
 
12. Consider the week-end as suitable for on-going data collection, but NOT for screening, as facility staff only are available during week-days.
 
13. Every BAG has a limited number of days available per year and no-one within a BAG will be able to book time once the BAGs quota has been used. Ensure therefore that you are aware of the number of days within the BAG allocation that are available for your project. If you are unsure contact your BAG representative. BE FAIR towards your BAG fellows and coordinate your bookings with them.
 
14. Consider that the number of days may vary during the year, depending on down-time and cancelling, so it is always a good idea to have look at the calendar and you might be able to book time left free by other BAGs or users.
 
15. Inform colleagues and friends that want to start using cryo-EM to contact us directly and apply for Rapid Access using our portal.
 
 
